==> musescore-snapshot_3.0%2Bdfsg1.orig.tar.xz: musescore-snapshot-3.0+dfsg1.orig/share/tours/tourxml.h <==
QT_TRANSLATE_NOOP3("TourXML", "MuseScore provides many ways to navigate through your score.\n    Click \"Next\" to learn more.", "navigate-tour"),
QT_TRANSLATE_NOOP3("TourXML", "The quickest way to scroll up and down is to use your mouse wheel or equivalent touch gesture (for example, two-finger swipe).\n    To scroll horizontally, hold Shift while using the mouse wheel or touch gesture.", "navigate-tour"),
QT_TRANSLATE_NOOP3("TourXML", "The navigation keys on your keyboard such as PgUp, PgDn, Home, and End function as in other applications\n    to move between pages.\n    Keyboards that lack these keys often provide equivalents such as Fn+Up/Down/Left/Right.", "navigate-tour"),
QT_TRANSLATE_NOOP3("TourXML", "You can move the score short distances by clicking an empty area of the page and dragging.\n    By the way, you can also select regions by holding Shift while dragging.", "navigate-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Additional navigation tools include the Timeline and Navigator, both found in the View menu.", "navigate-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Welcome to the Inspector, where you can change individual properties for selected elements.\n    Click \"Next\" to learn more.", "inspector-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Begin by selecting one or more elements in your score, then use the check boxes, spin boxes, dropdown menus, and other controls to change values for the various properties.\n    The set of properties available will differ according to the type of selected elements or elements.", "inspector-tour"),
QT_TRANSLATE_NOOP3("TourXML", "If you have selected elements of different types, only a few settings common to all elements will be available.\n    You can click the \"Notes\" and other buttons at the bottom of the Inspector to limit the selection to just the elements of the specified type.", "inspector-tour"),
QT_TRANSLATE_NOOP3("TourXML", "If you have modified a value, you can click the \"Reset\" button to reset it to the default.\n    If the value is controlled by a style setting, you can click the \"Set as style\" button to set the current value as the new default for the style.\n    You can also set style defaults using Format / Style.", "inspector-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Welcome to note input, where you will enter notes and rests into your score.\n    Click \"Next\" to learn more.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To enable note input mode, click the \"Note input\" icon or press the shortcut \"N\".", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "Select a duration by clicking one of these icons or pressing the shortcuts \"1\" - \"9\".\n    To include an augmentation dot, click the appropriate icon or press the shortcut \".\".", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To enter a note of the selected duration, type its letter name or click on the staff.\n    Press Ctrl+Up/Down (macOS: Cmd+Up/Down) to change octave.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To enter a rest of the selected duration, press the shortcut \"0\", or select this icon then click on the staff.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To add an accidental to a note, press the shortcut Up or Down to raise or lower its pitch,\n    or click one of these icons.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To add a note to a chord, press Shift while typing its letter name, or click on the staff.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To extend a note by adding a tied note, select the duration to extend by, then press \"+\" or click this button.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To create a triplet or other tuplet, select the duration representing the total length of the tuplet, then press Ctrl+number or use Add / Tuplets.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To enter notes with different rhythms in the same measure, use multiple voices.\n    Each staff can have up to four voices.\n    The default is voice 1, and it should be used first for each staff.\n    To enter notes into a different voice, click one of these icons.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "Welcome to MuseScore! This brief tour will guide you through the MuseScore user interface.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "This is the score view, where you can view and edit your score.\n    Use your mouse wheel or touchpad to scroll (with Shift to scroll horizontally).\n    If you have multiple scores open, you can switch between them using tabs at the top of your score view.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "These are the toolbars.\n    The main three are File Operations, Playback Controls, and Note Input.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "The File Operations toolbar allows you to create/save/open/print files and undo/redo changes.\n    You can also save to your musescore.com account if you go to File / Save Online.\n    The controls at the right of this toolbar control the display of your score.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "The Playback Controls toolbar allows you to play/pause your score and control various aspects of playback.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "The Note Input toolbar allows you to enter notes and rests into your score.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "The Palettes allow you to add most other notation elements to your score.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "The Inspector allows you to control various properties of the elements in your score.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "The main menu contains most other commands.\n    In addition, many commands can be accessed via keyboard shortcuts or by right-clicking (macOS: Ctrl+clicking) within the score view.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "That's the end of this tour!\n    As you use MuseScore, more tours will pop up to further explain functionality.\n    To disable these, deselect \"Continue showing tours\" before closing this window.\n    You can also enable/disable and reset tours in Help / Tours.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "Autoplace is a new feature that automatically detects and avoids many types of collisions between elements.\n    You can also manually adjust the position of autoplaced elements, or disable autoplace for selected elements.\n    Click \"Next\" to learn more.", "autoplace-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Autoplace positions most elements according to standard music engraving practice,\n    such as by moving tempo markings above other text or by shortening hairpins to avoid dynamics.\n    In many cases, this means that no further adjustments will be required at all.", "autoplace-tour"),
QT_TRANSLATE_NOOP3("TourXML", "If necessary, you can fine-tune the position of elements by dragging, by using the cursor keys while in Edit mode (double-click),\n    or by using the \"Offset\" fields in the Inspector.\n    This allows you to make adjustments while leaving autoplace enabled to continue avoiding collisions.", "autoplace-tour"),
QT_TRANSLATE_NOOP3("TourXML", "For larger adjustments, it may be more convenient to disable autoplace for selected elements using the Inspector.\n    This will remove them from collision detection and allow you to place them more freely.", "autoplace-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Welcome to the Palettes, where you will add various elements to your score. Click \"Next\" to learn more.", "show-palette"),
QT_TRANSLATE_NOOP3("TourXML", "Each palette contains items that can be added to the score.", "show-palette"),
QT_TRANSLATE_NOOP3("TourXML", "There are different workspaces available with different sets of palettes.\n    The \"Advanced\" workspace contains more items than the \"Basic\" workspace.", "show-palette"),
QT_TRANSLATE_NOOP3("TourXML", "To add a palette item to your score, first select an element or range in your score, then double-click on the palette item to add it to the selected elements.\n    You can also drag an item from the palette and drop it on a specific element in your score.", "show-palette"),
QT_TRANSLATE_NOOP3("TourXML", "You have toggled multimeasure rests in this score.\n    This combines multiple measures of rests into a single multimeasure rest.\n    To toggle this setting again, press the shortcut \"M\".", "mmrest"),
QT_TRANSLATE_NOOP3("TourXML", "Welcome to the Timeline, where you can view a high-level reduction of the score for easier navigation.\n    Click \"Next\" to learn more.", "timeline-tour"),
QT_TRANSLATE_NOOP3("TourXML", "The timeline shows rehearsal marks, changes of tempo, key, and time signature, and other points of interest.\n    You can click anywhere to jump to the corresponding location in your score.", "timeline-tour"),
QT_TRANSLATE_NOOP3("TourXML", "The section below contains a row for each instrument.\n    Each box within the row represents a measure for that instrument.\n    If the box is highlighted, then there are notes in that measure.\n    Boxes with a thin blue outline represent measures that are currently in view.", "timeline-tour"),
QT_TRANSLATE_NOOP3("TourXML", "MuseScore supports different types of selections: single, list, and range.\n    Click \"Next\" to learn more.", "select-tour"),
QT_TRANSLATE_NOOP3("TourXML", "To make a single selection, click the element you want to select.\n    It becomes highlighted to indicate that it is selected.\n    You can use the left and right cursor keys to move the selection through the notes and rests of your score.\n    Tip: if you press the Alt key (Option on macOS) along with the cursor keys you can move through other elements too,\n    and also move up and down from staff to staff.", "select-tour"),
QT_TRANSLATE_NOOP3("TourXML", "A list selection is a combination of single selections.\n    Press Ctrl (macOS: Cmd) while clicking to add or remove elements to the list selection.\n    You can also quickly select similar elements by right-clicking (macOS: Ctrl+clicking) one\n    and then choosing one of the \"Select\" options from the resulting popup menu.", "select-tour"),
QT_TRANSLATE_NOOP3("TourXML", "A range selection includes everything from one point in time to another across one or more staves.\n    It is indicated by a blue rectangle encompassing the entire range.\n    To make a range selection, click the first note, rest, or measure you want to select, then Shift+click the last.\n    You can also extend range selections by holding the Shift key while moving the cursor.", "select-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Another way to make selections is to hold Shift while dragging.\n    If your selection includes notes, it will automatically be made as a range selection;\n    otherwise it will be made as a list selection.", "select-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Finally, the Selection Filter (found in the View menu) allows you to exclude elements of a given type from a range selection.", "select-tour"),

==> musescore-snapshot_3.0.2%2Bdfsg1.orig.tar.xz: musescore-snapshot-3.0.2+dfsg1.orig/share/tours/tourxml.h <==
QT_TRANSLATE_NOOP3("TourXML", "MuseScore provides many ways to navigate through your score.\n    Click \"Next\" to learn more.", "navigate-tour"),
QT_TRANSLATE_NOOP3("TourXML", "The quickest way to scroll up and down is to use your mouse wheel or equivalent touch gesture (for example, two-finger swipe).\n    To scroll horizontally, hold Shift while using the mouse wheel or touch gesture.", "navigate-tour"),
QT_TRANSLATE_NOOP3("TourXML", "The navigation keys on your keyboard such as PgUp, PgDn, Home, and End function as in other applications\n    to move between pages.\n    Keyboards that lack these keys often provide equivalents such as Fn+Up/Down/Left/Right.", "navigate-tour"),
QT_TRANSLATE_NOOP3("TourXML", "You can move the score short distances by clicking an empty area of the page and dragging.\n    By the way, you can also select regions by holding Shift while dragging.", "navigate-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Additional navigation tools include the Timeline and Navigator, both found in the View menu.", "navigate-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Welcome to the Inspector, where you can change individual properties for selected elements.\n    Click \"Next\" to learn more.", "inspector-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Begin by selecting one or more elements in your score, then use the check boxes, spin boxes, dropdown menus, and other controls to change values for the various properties.\n    The set of properties available will differ according to the type of selected elements or elements.", "inspector-tour"),
QT_TRANSLATE_NOOP3("TourXML", "If you have selected elements of different types, only a few settings common to all elements will be available.\n    You can click the \"Notes\" and other buttons at the bottom of the Inspector to limit the selection to just the elements of the specified type.", "inspector-tour"),
QT_TRANSLATE_NOOP3("TourXML", "If you have modified a value, you can click the \"Reset\" button to reset it to the default.\n    If the value is controlled by a style setting, you can click the \"Set as style\" button to set the current value as the new default for the style.\n    You can also set style defaults using Format > Style….", "inspector-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Welcome to note input, where you will enter notes and rests into your score.\n    Click \"Next\" to learn more.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To enable note input mode, click the \"Note input\" icon or press the shortcut \"N\".", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "Select a duration by clicking one of these icons or pressing the shortcuts \"1\" - \"9\".\n    To include an augmentation dot, click the appropriate icon or press the shortcut \".\".", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To enter a note of the selected duration, type its letter name or click on the staff.\n    Press Ctrl+Up/Down (macOS: Cmd+Up/Down) to change octave.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To enter a rest of the selected duration, press the shortcut \"0\", or select this icon then click on the staff.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To add an accidental to a note, press the shortcut Up or Down to raise or lower its pitch,\n    or click one of these icons.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To add a note to a chord, press Shift while typing its letter name, or click on the staff.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To extend a note by adding a tied note, select the duration to extend by, then press \"+\" or click this button.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To create a triplet or other tuplet, select the duration representing the total length of the tuplet, then press Ctrl+number or use Add > Tuplets.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "To enter notes with different rhythms in the same measure, use multiple voices.\n    Each staff can have up to four voices.\n    The default is voice 1, and it should be used first for each staff.\n    To enter notes into a different voice, click one of these icons.", "note-input"),
QT_TRANSLATE_NOOP3("TourXML", "Welcome to MuseScore! This brief tour will guide you through the MuseScore user interface.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "This is the score view, where you can view and edit your score.\n    Use your mouse wheel or touchpad to scroll (with Shift to scroll horizontally).\n    If you have multiple scores open, you can switch between them using tabs at the top of your score view.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "These are the toolbars.\n    The main three are File Operations, Playback Controls, and Note Input.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "The File Operations toolbar allows you to create/save/open/print files and undo/redo changes.\n    You can also save to your musescore.com account if you go to File > Save Online.\n    The controls at the right of this toolbar control the display of your score.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "The Playback Controls toolbar allows you to play/pause your score and control various aspects of playback.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "The Note Input toolbar allows you to enter notes and rests into your score.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "The Palettes allow you to add most other notation elements to your score.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "The Inspector allows you to control various properties of the elements in your score.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "The main menu contains most other commands.\n    In addition, many commands can be accessed via keyboard shortcuts or by right-clicking (macOS: Ctrl+clicking) within the score view.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "That's the end of this tour!\n    As you use MuseScore, more tours will pop up to further explain functionality.\n    To disable these, deselect \"Continue showing tours\" before closing this window.\n    You can also enable/disable and reset tours in Help > Tours.", "welcome"),
QT_TRANSLATE_NOOP3("TourXML", "Autoplace is a new feature that automatically detects and avoids many types of collisions between elements.\n    You can also manually adjust the position of autoplaced elements, or disable autoplace for selected elements.\n    Click \"Next\" to learn more.", "autoplace-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Autoplace positions most elements according to standard music engraving practice,\n    such as by moving tempo markings above other text or by shortening hairpins to avoid dynamics.\n    In many cases, this means that no further adjustments will be required at all.", "autoplace-tour"),
QT_TRANSLATE_NOOP3("TourXML", "If necessary, you can fine-tune the position of elements by dragging, by using the cursor keys while in Edit mode (double-click),\n    or by using the \"Offset\" fields in the Inspector.\n    This allows you to make adjustments while leaving autoplace enabled to continue avoiding collisions.", "autoplace-tour"),
QT_TRANSLATE_NOOP3("TourXML", "For larger adjustments, it may be more convenient to disable autoplace for selected elements using the Inspector.\n    This will remove them from collision detection and allow you to place them more freely.", "autoplace-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Welcome to the Palettes, where you will add various elements to your score. Click \"Next\" to learn more.", "show-palette"),
QT_TRANSLATE_NOOP3("TourXML", "Each palette contains items that can be added to the score.", "show-palette"),
QT_TRANSLATE_NOOP3("TourXML", "There are different workspaces available with different sets of palettes.\n    The \"Advanced\" workspace contains more items than the \"Basic\" workspace.", "show-palette"),
QT_TRANSLATE_NOOP3("TourXML", "To add a palette item to your score, first select an element or range in your score, then double-click on the palette item to add it to the selected elements.\n    You can also drag an item from the palette and drop it on a specific element in your score.", "show-palette"),
QT_TRANSLATE_NOOP3("TourXML", "You have toggled multimeasure rests in this score.\n    This combines multiple measures of rests into a single multimeasure rest.\n    To toggle this setting again, press the shortcut \"M\".", "mmrest"),
QT_TRANSLATE_NOOP3("TourXML", "Welcome to the Timeline, where you can view a high-level reduction of the score for easier navigation.\n    Click \"Next\" to learn more.", "timeline-tour"),
QT_TRANSLATE_NOOP3("TourXML", "The timeline shows rehearsal marks, changes of tempo, key, and time signature, and other points of interest.\n    You can click anywhere to jump to the corresponding location in your score.", "timeline-tour"),
QT_TRANSLATE_NOOP3("TourXML", "The section below contains a row for each instrument.\n    Each box within the row represents a measure for that instrument.\n    If the box is highlighted, then there are notes in that measure.\n    Boxes with a thin blue outline represent measures that are currently in view.", "timeline-tour"),
QT_TRANSLATE_NOOP3("TourXML", "MuseScore supports different types of selections: single, list, and range.\n    Click \"Next\" to learn more.", "select-tour"),
QT_TRANSLATE_NOOP3("TourXML", "To make a single selection, click the element you want to select.\n    It becomes highlighted to indicate that it is selected.\n    You can use the left and right cursor keys to move the selection through the notes and rests of your score.\n    Tip: if you press the Alt key (Option on macOS) along with the cursor keys you can move through other elements too,\n    and also move up and down from staff to staff.", "select-tour"),
QT_TRANSLATE_NOOP3("TourXML", "A list selection is a combination of single selections.\n    Press Ctrl (macOS: Cmd) while clicking to add or remove elements to the list selection.\n    You can also quickly select similar elements by right-clicking (macOS: Ctrl+clicking) one\n    and then choosing one of the \"Select\" options from the resulting popup menu.", "select-tour"),
QT_TRANSLATE_NOOP3("TourXML", "A range selection includes everything from one point in time to another across one or more staves.\n    It is indicated by a blue rectangle encompassing the entire range.\n    To make a range selection, click the first note, rest, or measure you want to select, then Shift+click the last.\n    You can also extend range selections by holding the Shift key while moving the cursor.", "select-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Another way to make selections is to hold Shift while dragging.\n    If your selection includes notes, it will automatically be made as a range selection;\n    otherwise it will be made as a list selection.", "select-tour"),
QT_TRANSLATE_NOOP3("TourXML", "Finally, the Selection Filter (found in the View menu) allows you to exclude elements of a given type from a range selection.", "select-tour"),
